(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     21970,        604]*)
(*NotebookOutlinePosition[     22686,        629]*)
(*  CellTagsIndexPosition[     22642,        625]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["NMR", "Title",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "In NMR experiments, transitions between different states of a quantum \
mechanical system are induced via a periodic field, usually much weaker than \
typical fields of the system itself. Its frequency, however, must be \
comparable to the energy difference between the states (\[HBar]\[Omega] \
\[TildeTilde] \[CapitalDelta]E) to have any effect. If \[HBar]\[Omega] = \
\[CapitalDelta]E, all particles can be transferred from their original state \
to another and back again in a periodic cycle. Its frequency is the so called \
",
  StyleBox["Rabi frequency",
    FontWeight->"Bold"],
  ".\nThis notebook considers a two-state system, namely a ",
  Cell[BoxData[
      \(TraditionalForm\`Spin - 1\/2\)]],
  "particle in a constant magnetic field. The time dependent \
Schr\[ODoubleDot]dinger equation for this system with an additional periodic \
magnetic field is solved numerically. The Rabi frequency and the minimal \
population of the original state are then determined for different strengths \
and frequencies of the perturbation."
}], "Text"],

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\  (*Clear\ all\ previous\ global\ settings\ \
from\ currently\ open\ sessions*) \), "\n", 
    \(Needs["\<Statistics`NonlinearFit`\>"]; 
    Needs["\<Graphics`MultipleListPlot`\>"];\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Schr\[ODoubleDot]dinger equation", "Section"],

Cell[TextData[{
  "The Hamiltonian of a Spin-1/2 particle in a homogenous, constant magnetic \
field in z-direction is:\n\n",
  Cell[BoxData[
      \(TraditionalForm\`H\_0 = \ \(\(e\ g\)\/\(2\ m\)\) \(B\_z\) S\_z\)],
    FontColor->GrayLevel[0]],
  StyleBox["\t,\t",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`S\_z = \(\[HBar]\/2\) \[Sigma]\_3\)],
    FontColor->GrayLevel[0]],
  "\n\nwith ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            FormBox[\(\[Omega]\_0\),
              "TraditionalForm"], "=", \(\(e\ g\ B\_z\)\/\(2  m\)\)}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  ", this becomes:\n\n",
  Cell[BoxData[
      \(TraditionalForm\`H\_0 = \ \(\[Omega]\_0\) S\_z\)],
    FontColor->GrayLevel[0]],
  "\n\nThe eigenvalues of this Hamiltonian are ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{\(E\_\[Sigma]\), "=", 
            RowBox[{
              FractionBox[
                StyleBox["\[Sigma]",
                  FontColor->GrayLevel[0]], "2"], 
              " ", \(\[HBar]\[Omega]\_0\)}]}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  ", with ",
  StyleBox["\[Sigma]=\[PlusMinus]1",
    FontColor->GrayLevel[0]],
  ". The probability of finding the system in one of these eigenvectors is \
time-independent:\n\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            RowBox[{
              FormBox["|",
                
                "TraditionalForm"], \(\[LeftAngleBracket]\[Sigma] | \[Psi](
                    t)\[RightAngleBracket]\), \( | \^2\)}], "="}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            FormBox["|",
              
              "TraditionalForm"], \(\[LeftAngleBracket]\[Sigma] | 
                e\^\(\(\(-it\)\/\[HBar]\) H\) | \[Psi](
                  t = 0)\[RightAngleBracket]\), \( | \^2\)}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  StyleBox["= ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\(|\)\(e\^\(\(it\/\[HBar]\) E\_\[Sigma]\)\)\),
              
              "TraditionalForm"], \(\[LeftAngleBracket]\[Sigma] | \[Psi](
                  0)\[RightAngleBracket]\)}], \( | \^2\)}], TraditionalForm]],
    
    FontColor->GrayLevel[0]],
  StyleBox["= ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[LeftAngleBracket]\[Sigma] | \[Psi](
              0)\[RightAngleBracket]\)\( | \^2\)\)\)],
    FontColor->GrayLevel[0]],
  "\n\nIn order to obtain a transition between the eigenstates, we need a \
time-dependent Hamiltonian. One possibility is an additional periodic field \
in x-direction:\n\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(H = H\_0\),
          FontColor->GrayLevel[0]], TraditionalForm]]],
  StyleBox[" + ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\(\(e\ g\)\/\(2\ m\)\) \(B\_x\) \(cos(\[Omega]t)\) S\_x\),
            
            "TraditionalForm"], "=", 
          RowBox[{
            FormBox[\(\(\[Omega]\_0\) S\_z\),
              "TraditionalForm"], 
            "+", \(\(\[Omega]\_1\) \(cos(\[Omega]t)\) S\_x\)}]}], 
        TraditionalForm]],
    FontColor->GrayLevel[0]],
  "\n\nWe express H and |\[Psi](t)\[RightAngleBracket] in  the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\_z - basis\)\(,\)\)\)]],
  " the eigenbasis of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(H\_0\)\(,\)\(\ \)\)\)]],
  "the eigenvectors are ",
  StyleBox["|+z\[RightAngleBracket]=",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"1"},
              {"0"}
              }], ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  " for ",
  StyleBox["\[Sigma]=+1",
    FontColor->GrayLevel[0]],
  " and ",
  StyleBox["|-z\[RightAngleBracket]=",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NegativeThinSpace]", ")"}],
              FontColor->GrayLevel[0]], " ", "for", " ", 
            StyleBox["\[Sigma]",
              FontColor->GrayLevel[0]]}], 
          StyleBox["=",
            FontColor->GrayLevel[0]], 
          StyleBox[\(\(-1\)\(:\)\),
            FontColor->GrayLevel[0]]}], TraditionalForm]]]
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.847059]],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\[Sigma]\_1\), " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0", "1"},
              {"1", "0"}
              }], ")"}]}], ";", "  ", 
      RowBox[{\(\[Sigma]\_2\), " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0", \(-\[ImaginaryI]\)},
              {"\[ImaginaryI]", "0"}
              }], ")"}]}], ";", "  ", 
      RowBox[{\(\[Sigma]\_3\), " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"1", "0"},
              {"0", \(-1\)}
              }], ")"}]}], ";"}]], "Input"],

Cell[BoxData[{
    \(\(H\_0 = \[Omega]\_0\ \[Sigma]\_3/2;\)\), "\[IndentingNewLine]", 
    \(H = H\_0 + \(\[Omega]\_1\/2\) Cos[\[Omega]\ t]\ \[Sigma]\_1; 
    H // MatrixForm\)}], "Input"],

Cell[TextData[{
  "\nWith \t",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            RowBox[{
              RowBox[{
                
                FormBox[\(\(\(\(|\)\(\[Psi](
                          t)\)\)\(\[RightAngleBracket]\)\) = \[Sum]\+\[Sigma]\
\),
                  "TraditionalForm"], \(\(C\_\[Sigma]\)(t)\)}], "|", 
              "\[Sigma]"}], "\[RightAngleBracket]"}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  StyleBox["=",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(a(t)\)},
              {\(b(t)\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  ",\n\nthe time-dependent Schroedinger equation becomes:\n\n",
  Cell[BoxData[
      \(TraditionalForm\`i \[PartialD]\/\[PartialD]t\)],
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(a(t)\)},
              {\(b(t)\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  StyleBox["=H ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {\(a(t)\)},
                  {\(b(t)\)}
                  }], "\[NegativeThinSpace]", ")"}],
            "TraditionalForm"], "=", \(1\/2\)}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(\[Omega]\_0\), \(\(\[Omega]\_1\) \(cos(\[Omega]t)\)\)},
              {\(\(\[Omega]\_1\) \(cos(\[Omega]t)\)\), \(-\[Omega]\_0\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(a(t)\)},
              {\(b(t)\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]]
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.847059]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical Solution", "Section"],

Cell["\<\
We solve this equation for the coefficients a(t) and b(t) \
numerically.\
\>", "Text"],

Cell[BoxData[
    \(\(numsol[\[Omega]0_, \[Omega]1_, \ \[Omega]_] := 
        Block[{sol, t}, \[IndentingNewLine]\[Omega]est = 
            Max[\((\[Omega] - \[Omega]0)\), \[Omega]1/
                2]; \[IndentingNewLine]tmax = 
            N[2  \[Pi]/\[Omega]est]; \[IndentingNewLine]sol = 
            NDSolve[{I\ \(a'\)[
                      t] \[Equal] \[Omega]0\ a[t]/
                        2 + \[Omega]1\ Cos[\[Omega]\ t]\ b[t]/2, 
                I\ \(b'\)[
                      t] == \(-\[Omega]0\)\ b[t]/
                        2\  + \[Omega]1\ Cos[\[Omega]\ t]\ a[t]/2, 
                a[0] \[Equal] 1, b[0] \[Equal] 0}, {a[t], b[t]}, {t, 0, \ 
                tmax}]; \[IndentingNewLine]pup[t_] = 
            Abs[a[t]]\^2 /. sol[\([1]\)]; \[IndentingNewLine]pdown[t_] = 
            Abs[b[t]]\^2 /. sol[\([1]\)];\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[{
    \(\(numsol[\[Omega]0 = 1, \[Omega]1 = 0.1, \[Omega] = 
          0.95];\)\), "\[IndentingNewLine]", 
    \(\(plOsc = 
        Plot[{pup[t], pdown[t]}, {t, 0, \ tmax}, 
          PlotRange \[Rule] {{0, 1.1  tmax}, {0, 1}}, 
          PlotStyle \[Rule] {Hue[1], Hue[0.6]}, 
          AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
          DisplayFunction -> Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[plOsc, 
        Graphics[{Text[\*"\"\<|a(t)\!\(\( | \^2\)\)\>\"", {1.1\ tmax, 
                pup[tmax]}, TextStyle \[Rule] {FontColor -> Hue[1]}], 
            Text[\*"\"\<|b(t)\!\(\( | \^2\)\)\>\"", {1.1\ tmax, pdown[tmax]}, 
              TextStyle \[Rule] {FontColor -> Hue[0.6]}]}], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell["\<\

The probabilities to find the state in a particular eigenstate are now time \
dependent, we obtain a superposition of a fast and a slow oscillation. The \
frequency of the slow oscillation is called the Rabi frequency.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rabi Frequency", "Section"],

Cell[TextData[{
  "In order to find the involved frequencies, we perform a Fourier transform \
on ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(a(t)\)\( | \^2\)\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\( \
(*Fourier*) \)\(\[IndentingNewLine]\)\(numfourier[fname_, tmax_] := 
        Block[{t, n00, n0m1, n0p1, nmax = 250, at, lmax, 
            i}, \[IndentingNewLine]func[t_] = 
            fname[t]; \[IndentingNewLine]meanpop = 
            NIntegrate[func[t], {t, 0, tmax}]/tmax; \[IndentingNewLine]at = 
            Table[func[i\ tmax\/nmax], {i, 0, nmax}] - 
              meanpop; \[IndentingNewLine]fA = 
            Fourier[at]; \[IndentingNewLine]lmax = 
            Position[Abs[Take[fA, Round[nmax/2]]], 
              Max[Abs[Take[fA, Round[nmax/2]]]]]; \[IndentingNewLine]n00 = 
            Min[Flatten[
                lmax]]; \[IndentingNewLine] (*to\ slightly\ impltove\ the\ \
accuracy\ of\ the\ \(\(result\)\(:\)\)*) \[IndentingNewLine]n0m1 = 
            Max[n00 - 1, 1]; \[IndentingNewLine]n0p1 = 
            n00 + 1; \[IndentingNewLine]n0 = \((n00*Abs[fA[\([n00]\)]] + 
                    n0m1*Abs[fA[\([n0m1]\)]] + 
                    n0p1*Abs[fA[\([n0p1]\)]])\)/\((Abs[fA[\([n00]\)]] + 
                    Abs[fA[\([n0m1]\)]] + Abs[fA[\([n0p1]\)]])\) - 
              1;\[IndentingNewLine]];\)\)\)], "Input"],

Cell[BoxData[{
    \(\(numfourier[pup, tmax];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Abs[fA], \ PlotJoined \[Rule] True, 
        PlotRange \[Rule] {{0, 100}, All}, PlotStyle \[Rule] {Hue[1]}, 
        AxesLabel \[Rule] {"\<\[Omega]\>", "\<\>"}];\)\)}], "Input"],

Cell["\<\

We get a large peak at a low frequency (the Rabi frequency) and a small peak \
at a high frequency. The approximate Rabi frequency is: \
\>", "Text"],

Cell[BoxData[
    \(\(Print[\*"\"\<\!\(\[Omega]\_R\)= \>\"", \[Omega]est\ n0];\)\)], "Input"],

Cell["\<\
Unfortunately, the frequency resolution is not very good and we \
need an additional nonlinear fit. We will use the frequency obtained from the \
Fourier transform as a starring value for this fit:\
\>", "Text"],

Cell[BoxData[
    \(\(\( (*Nonlinear\ Fit*) \)\(\[IndentingNewLine]\)\( (*The\ starting\ \
value\ for\ the\ frequency\ needs\ to\ be\ quite\ \(close!\)*) \)\(\
\[IndentingNewLine]\)\(cosfit[funcname_, offset_, amplitude_, frequency_] := 
        Block[{nmax = 250, afit, i, t, amp1, a0, 
            n1}, \[IndentingNewLine]func[t_] = 
            funcname[t]; \[IndentingNewLine]afit = 
            Table[{N[\(\(\ \)\(i\)\)\/nmax], 
                func[N[i\ \(\(\ \)\(tmax\)\)\/nmax]]}, {i, 0, 
                nmax}]; \[IndentingNewLine]fitres = 
            BestFitParameters /. 
              NonlinearRegress[afit, a0 + amp1\ Cos[2\ \[Pi]\ n1\ t], 
                t, {{a0, offset}, {amp1, amplitude}, {n1, frequency}}, 
                RegressionReport \[Rule] 
                  BestFitParameters];\[IndentingNewLine]];\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cosfit[pup, meanpop, 1 - meanpop, n0];\)\), "\[IndentingNewLine]", 
    \(\(\[Omega]R = \[Omega]est\ n1 /. fitres;\)\), "\[IndentingNewLine]", 
    \(\(ampR = amp1 /. fitres;\)\), "\[IndentingNewLine]", 
    \(\(meanpop = a0 /. fitres;\)\), "\[IndentingNewLine]", 
    \(\(plfit = 
        Plot[{meanpop + ampR\ Cos[\[Omega]R\ t], pup[t]}, {t, 0, tmax}, 
          PlotStyle \[Rule] {{Hue[1], Thickness[0.01]}, {GrayLevel[0]}}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[plfit, 
        Graphics[{Text["\<fit\>", {\ tmax, meanpop}, 
              TextStyle \[Rule] {FontColor \[Rule] Hue[1]}], 
            Text[\*"\"\<|a(t)\!\(\( | \^2\)\)\>\"", {\ tmax, 
                meanpop - ampR/2}]}], AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Mean Propability of measuring |+z\[RightAngleBracket]: \>", 
        meanpop];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Amplitude of oscillation: \>", 
        ampR];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rabi frequency: \>", \[Omega]R, "\<  Period of \
Rabi-oscillation: \>", 2\ \[Pi]/\[Omega]R];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Mean Propability of measuring \
|+z\[RightAngleBracket]: "\[InvisibleSpace]0.7466351778359953`\),
      SequenceForm[ 
      "Mean Propability of measuring |+z\[RightAngleBracket]: ", 
        0.74663517783599531],
      Editable->False]], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    InterpretationBox[\("Amplitude of oscillation: \
"\[InvisibleSpace]0.25303634809794956`\),
      SequenceForm[ "Amplitude of oscillation: ", 0.25303634809794956],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rabi frequency: \
"\[InvisibleSpace]0.07115959075460786`\[InvisibleSpace]"  Period of \
Rabi-oscillation: "\[InvisibleSpace]88.29709727880534`\),
      SequenceForm[ 
      "Rabi frequency: ", 0.071159590754607857, 
        "  Period of Rabi-oscillation: ", 88.297097278805339],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameter Dependence", "Section"],

Cell["\<\
We want to observe the effect of a variation in \[Omega]1 and \
\[Omega], i.e. the strength and the frequency of the perturbation, on the \
Rabi frequency and the amplitude.\
\>", "Text"],

Cell[BoxData[
    \(\[Omega]1list = {0.05, 0.075, 0.1, 0.15, 0.2, 0.25, 
        0.3}; \[Omega]list = {0.8, 0.9, 0.95, 0.99, 1, 1.01, 1.05, 1.1, 1.2}; 
    colldata = 
      Table[Table[{0, 0, 0, 
            0\ }, {Length[\[Omega]1list]}], {Length[\[Omega]list]}];\)], \
"Input"],

Cell["This may take some time:", "Text"],

Cell[BoxData[{
    \(imax = Length[\[Omega]list]; 
    jmax = Length[\[Omega]1list];\), "\[IndentingNewLine]", 
    \(\(Do[\(Do[\[IndentingNewLine]numsol[
              1, \[Omega]1list[\([j]\)], \[Omega]list[\([i]\)]]; \
\[IndentingNewLine]numfourier[pup, tmax]; \[IndentingNewLine]cosfit[pup, 
              meanpop, 1 - meanpop, 
              n0]; \[IndentingNewLine]\[Omega]R = \[Omega]est\ n1 /. 
                fitres; \[IndentingNewLine]ampR = 
              amp1 /. fitres; \[IndentingNewLine] (*\(Print["\<\[Omega]1= \
\>", \[Omega]1list[\([j]\)], "\< \[RawEscape]\[Omega]= \>", \
\[Omega]list[\([i]\)], \*"\"\<    \!\(\[Omega]\_R\)= \>\"", \[Omega]R, "\<  \
Amplitude: \>", ampR];\)*) \[IndentingNewLine]colldata[\([i, 
                  j]\)] = {\[Omega]1list[\([j]\)], \[Omega]list[\([i]\)], \
\[Omega]R, ampR};\[IndentingNewLine], {j, 1, 
              jmax}];\)\[IndentingNewLine], {i, 1, imax}];\)\)}], "Input"],

Cell[TextData[{
  "The Rabi frequency as a function of the frequency \[Omega] of the \
perturbation and of its strength ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(plFreq = 
        Show[Graphics3D[{Line /@ 
                Transpose[colldata[\([All, All, {2, 1, 3}]\)]], 
              Line /@ colldata[\([All, All, {2, 1, 3}]\)]}\ , 
            Boxed \[Rule] True, Axes \[Rule] True, 
            AxesLabel \[Rule] {\*"\"\<\[Omega]1/\!\(\[Omega]\_0\)\>\"", \*"\"\
\<\[Omega]/\!\(\[Omega]\_0\)\>\"", \*"\"\<\!\(\[Omega]\_R\)/\!\(\[Omega]\_0\)\
\>\""}, PlotLabel -> "\<Rabi frequency\>"]];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Save plot to ps-file", "Subsubsection"],

Cell[BoxData[{
    \(\(SetDirectory["\<~/mathem\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<rabifreq.eps\>", plFreq, "\<EPS\>"];\)\)}], "Input"],

Cell["\<\

The amplitude of the Rabi oscillation:\
\>", "Text"],

Cell[BoxData[
    \(\(plAmp = 
        Show[Graphics3D[{Line /@ 
                Transpose[colldata[\([All, All, {2, 1, 4}]\)]], 
              Line /@ colldata[\([All, All, {2, 1, 4}]\)]}\ , 
            Axes \[Rule] True, 
            AxesLabel \[Rule] {\*"\"\<\[Omega]/\!\(\[Omega]\_0\)\>\"", \
\*"\"\<\[Omega]1/\!\(\[Omega]\_0\)\>\"", "\<\>"}, 
            AxesEdge \[Rule] {{\(-1\), \(-1\)}, {1, \(-1\)}, {\(-1\), \
\(-1\)}}, PlotLabel -> "\<Amplitude\>"]];\)\)], "Input"],

Cell[TextData[{
  "We see, that the oscillation is stronger for \[Omega] close to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_0\)]],
  ". For ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \[Omega]\_0\)]],
  ", all particles go from |+z\[RightAngleBracket] at the beginning to |-z\
\[RightAngleBracket] at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]/\[Omega]\_R\)]],
  ". Outside this resonance, some particles remain in the |+z\
\[RightAngleBracket] state."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save plot to ps-file", "Subsubsection"],

Cell[BoxData[{
    \(\(SetDirectory["\<~/mathem\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<rabiamp.eps\>", plAmp, "\<EPS\>"];\)\)}], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowToolbars->"EditBar",
WindowSize->{1269, 916},
WindowMargins->{{0, Automatic}, {Automatic, 28}},
Magnification->1.25,
StyleDefinitions -> "PastelColor.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 45, 1, 130, "Title"],

Cell[CellGroupData[{
Cell[1797, 57, 31, 0, 61, "Section"],
Cell[1831, 59, 1071, 19, 169, "Text"],
Cell[2905, 80, 243, 4, 87, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3185, 89, 51, 0, 61, "Section"],
Cell[3239, 91, 4710, 141, 475, "Text"],
Cell[7952, 234, 565, 16, 60, "Input"],
Cell[8520, 252, 188, 3, 88, "Input"],
Cell[8711, 257, 2221, 65, 192, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10969, 327, 37, 0, 61, "Section"],
Cell[11009, 329, 96, 3, 36, "Text"],
Cell[11108, 334, 867, 15, 194, "Input"],
Cell[11978, 351, 777, 14, 131, "Input"],
Cell[12758, 367, 243, 5, 88, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13038, 377, 33, 0, 61, "Section"],
Cell[13074, 379, 192, 6, 36, "Text"],
Cell[13269, 387, 1180, 20, 351, "Input"],
Cell[14452, 409, 269, 4, 66, "Input"],
Cell[14724, 415, 160, 4, 62, "Text"],
Cell[14887, 421, 93, 1, 45, "Input"],
Cell[14983, 424, 221, 4, 62, "Text"],
Cell[15207, 430, 844, 14, 227, "Input"],

Cell[CellGroupData[{
Cell[16076, 448, 1226, 21, 256, "Input"],
Cell[17305, 471, 339, 8, 47, "Print"],
Cell[17647, 481, 214, 4, 47, "Print"],
Cell[17864, 487, 351, 7, 47, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18264, 500, 39, 0, 61, "Section"],
Cell[18306, 502, 197, 4, 36, "Text"],
Cell[18506, 508, 280, 6, 66, "Input"],
Cell[18789, 516, 40, 0, 36, "Text"],
Cell[18832, 518, 928, 15, 255, "Input"],
Cell[19763, 535, 198, 6, 36, "Text"],
Cell[19964, 543, 463, 8, 66, "Input"],

Cell[CellGroupData[{
Cell[20452, 555, 45, 0, 37, "Subsubsection"],
Cell[20500, 557, 152, 2, 66, "Input"],
Cell[20655, 561, 63, 3, 62, "Text"],
Cell[20721, 566, 477, 9, 66, "Input"],
Cell[21201, 577, 494, 13, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21732, 595, 45, 0, 37, "Subsubsection"],
Cell[21780, 597, 150, 2, 66, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

